@@ -4,6 +4,7 @@ trainControl <- function(method = "boot",
                          verboseIter = FALSE,
                          returnData = TRUE,
                          returnResamp = "final",
+                         savePredictions = FALSE,
                          p = .75,
                          classProbs = FALSE,
                          summaryFunction = defaultSummary,
@@ -37,6 +38,7 @@ trainControl <- function(method = "boot",
        verboseIter = verboseIter,
        returnData = returnData,
        returnResamp = returnResamp,
+       savePredictions = savePredictions,
        p = p,
        classProbs = classProbs,
        summaryFunction = summaryFunction,
